==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/admsC.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef adms_h
#define adms_h

#include <admsObject/admsH.h>
#include <admsObject/objectAdmselement.h>
#include <admsObject/objectAdmsattribute.h>
#include <admsObject/objectAdms.h>
#include <admsObject/objectSimulator.h>
#include <admsObject/objectAdmsmain.h>
#include <admsObject/objectAttribute.h>
#include <admsObject/objectList.h>
#include <admsObject/objectNature.h>
#include <admsObject/objectDiscipline.h>
#include <admsObject/objectModule.h>
#include <admsObject/objectAnalogfunction.h>
#include <admsObject/objectNodealias.h>
#include <admsObject/objectNode.h>
#include <admsObject/objectBranchalias.h>
#include <admsObject/objectBranch.h>
#include <admsObject/objectSource.h>
#include <admsObject/objectRange.h>
#include <admsObject/objectJacobian.h>
#include <admsObject/objectAnalog.h>
#include <admsObject/objectMath.h>
#include <admsObject/objectSubexpression.h>
#include <admsObject/objectMapply_unary.h>
#include <admsObject/objectMapply_binary.h>
#include <admsObject/objectMapply_ternary.h>
#include <admsObject/objectNumber.h>
#include <admsObject/objectString.h>
#include <admsObject/objectFunction.h>
#include <admsObject/objectVariable.h>
#include <admsObject/objectProbe.h>
#include <admsObject/objectExpression.h>
#include <admsObject/objectInstance.h>
#include <admsObject/objectInstanceparameter.h>
#include <admsObject/objectInstancenode.h>
#include <admsObject/objectNilled.h>
#include <admsObject/objectAssignment.h>
#include <admsObject/objectContribution.h>
#include <admsObject/objectConditional.h>
#include <admsObject/objectWhileloop.h>
#include <admsObject/objectCase.h>
#include <admsObject/objectCaseitem.h>
#include <admsObject/objectBlockvariable.h>
#include <admsObject/objectBlock.h>
#include <admsObject/objectCallfunction.h>
#include <admsObject/objectEvaluation.h>
#include <admsObject/objectProduction.h>
#include <admsObject/objectAdmst.h>
#include <admsObject/objectAdmsttransform.h>
#include <admsObject/objectInstanceofadmsttransform.h>
#include <admsObject/objectAdmstvariable.h>
#include <admsObject/objectPath.h>
#include <admsObject/objectLexval.h>
#include <admsObject/objectYaccval.h>
#endif /* adms_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/admsC.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef adms_h
#define adms_h

#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
#include <admsObject/objectSimulator.h>
#include <admsObject/objectAdmsmain.h>
#include <admsObject/objectAttribute.h>
#include <admsObject/objectEnumeration.h>
#include <admsObject/objectInteger.h>
#include <admsObject/objectReal.h>
#include <admsObject/objectQuark.h>
#include <admsObject/objectList.h>
#include <admsObject/objectNature.h>
#include <admsObject/objectDiscipline.h>
#include <admsObject/objectModule.h>
#include <admsObject/objectAnalogfunction.h>
#include <admsObject/objectNodealias.h>
#include <admsObject/objectNode.h>
#include <admsObject/objectBranchalias.h>
#include <admsObject/objectBranch.h>
#include <admsObject/objectSource.h>
#include <admsObject/objectRange.h>
#include <admsObject/objectJacobian.h>
#include <admsObject/objectAnalog.h>
#include <admsObject/objectMath.h>
#include <admsObject/objectString.h>
#include <admsObject/objectSubexpression.h>
#include <admsObject/objectMapply_unary.h>
#include <admsObject/objectMapply_binary.h>
#include <admsObject/objectMapply_ternary.h>
#include <admsObject/objectNumber.h>
#include <admsObject/objectFunction.h>
#include <admsObject/objectVariable.h>
#include <admsObject/objectProbe.h>
#include <admsObject/objectExpression.h>
#include <admsObject/objectInstance.h>
#include <admsObject/objectInstanceparameter.h>
#include <admsObject/objectInstancenode.h>
#include <admsObject/objectNilled.h>
#include <admsObject/objectAssignment.h>
#include <admsObject/objectContribution.h>
#include <admsObject/objectConditional.h>
#include <admsObject/objectWhileloop.h>
#include <admsObject/objectCase.h>
#include <admsObject/objectCaseitem.h>
#include <admsObject/objectBlockvariable.h>
#include <admsObject/objectBlock.h>
#include <admsObject/objectCallfunction.h>
#include <admsObject/objectEvaluation.h>
#include <admsObject/objectAdmsttext.h>
#include <admsObject/objectAdmstpath.h>
#include <admsObject/objectAdmstpathgoto.h>
#include <admsObject/objectAdmstpathevaluate.h>
#include <admsObject/objectAdmstpathparser.h>
#include <admsObject/objectAdmst.h>
#include <admsObject/objectAdmsttransformattribute.h>
#include <admsObject/objectAdmsttransform.h>
#include <admsObject/objectInstanceofadmsttransform.h>
#include <admsObject/objectAdmstvariable.h>
#include <admsObject/objectPath.h>
#include <admsObject/objectLexval.h>
#include <admsObject/objectYaccval.h>
#endif /* adms_h */
